@@ -14,8 +14,8 @@ const BASE: &str = "/_matrix/client/v3/";
 #[derive(Clone, Debug, Serialize, Deserialize, Default)]
 pub struct StorageData {
     pub auth_token: String,
-    pub room_to_aliases: BTreeMap<RoomId, Vec<RoomAliasId>>,
-    pub alias_to_room: BTreeMap<RoomAliasId, RoomId>,
+    //pub room_to_aliases: BTreeMap<RoomId, Vec<RoomAliasId>>,
+    //pub alias_to_room: BTreeMap<RoomAliasId, RoomId>,
     pub joined_rooms: Vec<RoomId>,
     pub room_to_name: BTreeMap<RoomId, Box<RoomName>>,
 }
@@ -354,7 +354,7 @@ impl Client {
             Ok(x)
         }
     }
-    pub fn join_with_alias(&mut self, alias: impl Into<String>) {
+    pub fn join_with_alias(&self, alias: impl Into<String>) {
         //self.post(format!("join/{}", urlencoding::encode(alias.into())), content, None).unwrap().into_json().unwrap()
         let room_alias = alias.into(); //format!("{}", alias.into());
         let this_room_id_val: Value = self
@@ -375,6 +375,20 @@ impl Client {
         //self.data.room_to_aliases.insert(room_id.clone(), vec![room_alias.try_into().unwrap()]);
         self.join_room_id(room_id);
     }
+    pub fn leave_room_id(&mut self, room_id: RoomId) -> Value {
+        let rid = room_id.to_string();
+        let room = urlencoding::encode(rid.as_str());
+        let content = json!({});
+        let output = self
+            .post(format!("rooms/{}/leave", room).as_str(), content, None)
+            .unwrap()
+            .into_json()
+            .unwrap();
+        self.data.joined_rooms.retain(|x| x != &room_id);
+        //self.data.room_to_name.remove(&room_id);
+        self.room_list_updated = true;
+        output
+    }
     pub fn room_id_from_alias(&self, alias: impl Into<String>) -> RoomId {
         let room_alias = alias.into(); //format!("{}", alias.into());
         let this_room_id_val: Value = self
@@ -431,6 +445,7 @@ impl Client {
             for event in joined_room.state.events.clone() {
                 //let ev = event.deserialize().unwrap();
                 if let Ok(ev) = event.deserialize() {
+                    /*
                     if let ruma::events::AnySyncStateEvent::RoomAliases(room_aliases_event) =
                         ev.clone()
                     {
@@ -459,7 +474,8 @@ impl Client {
                             }
                             //instructions.push(Instructions::SaveRoomAlias(room_id.clone(), alias));
                         }
-                    } //else if let ruma::events::AnySyncStateEvent::RoomCanonicalAlias
+                    } */
+                    //else if let ruma::events::AnySyncStateEvent::RoomCanonicalAlias
                     if let ruma::events::AnySyncStateEvent::RoomName(room_name_event) = ev.clone() {
                         if let Some(room_name) = room_name_event.content.name {
                             self.data.room_to_name.insert(room_id.clone(), room_name);
